@@ -220,4 +220,9 @@ def logger(logFile, logMsg, printLogMsg):
 
     if(printLogMsg is True):
         print(logMsg)
-    logFile.write('\n' + str((sys.argv[0]).rsplit('/', 1))[-1]) + " " + str(times()['day'][:3]) + " " + str(times()['month'][:3]) + " " + str(times()['date']) + " " + str(time.tzname[0]) + " " + str(times()['year']) + " - " + str(logMsg) + "\n")
\ No newline at end of file
+
+    program = sys.argv[0]
+    program = program.rsplit('/', 1)[-1]
+    logFile.write('\n' + str(program) + " " + str(times()['day'][:3]) + " " + str(times()['month'][:3]) + " " + str(times()['date']) + " " + str(time.tzname[0]) + " " + str(times()['year']) + " - " + str(logMsg) + "\n")
+
+    # logFile.write('\n' + sys.argv[0] + " " + times()['day'][:3] + " " + times()['month'][:3] + " " + times()['date'] + " " + time.tzname[0] + " " + times()['year'] + " - " + str(logMsg + "\n")
\ No newline at end of file
